yakumo.cinder.v2.quota_set

Package yakumo :: Package cinder :: Package v2 :: Module quota_set |
[hide private]
[frames] | no frames]

# Module quota_set

source code

Resource class and its manager for Quota sets in Block Storage API v2

Classes | [hide private]
| Resource Resource class for Quota sets in Block Storage API v2
| Manager Manager class for Quota sets in Block Storage API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('volumes', 'volumes', mapper.Noop), ('per
      _volume_gigabytes', 'per_volume_gigabytes', mapper.Noop), ('snapshots'
      , 'snapshots', mapper.Noop), ('gigabytes', 'gigabytes', mapper.Noop),
      ('backups', 'backups', mapper.Noop), ('backup_gigabytes', 'backup_giga
      bytes', mapper.Noop),]